/*
 *  numtracks.c
 *
 *  A simple program that reads the tracks number of a CD and write
 * it on stdout.
 *
 */

#include <stdio.h>
#include <fcntl.h>
#include <linux/cdrom.h>

#define CDROM_DEVICE "/dev/cdrom"

void fatal_error( char *text );

int
main( int argc, char *argv[] )
{
  int drive, d;
  struct cdrom_tochdr *tochdr = 0;

  /* Open the drive for reading. */
  if( ( drive = open( CDROM_DEVICE, O_RDONLY | O_NONBLOCK ) ) == -1 )
  {
      fprintf( stderr, "numtracks: opening device %s failed\n", CDROM_DEVICE );
      exit( 1 );
  }

 /* Is there a CD in the drive? */
 if( ioctl( drive, CDROM_DRIVE_STATUS ) != CDS_DISC_OK )
 {
     fprintf( stderr, "numtracks: no CD inserted in %s\n", CDROM_DEVICE );
     exit( 1 );
 }

 /* Is it an Audio CD? */
 if( ioctl( drive, CDROM_DISC_STATUS ) != CDS_AUDIO )
 {
     fprintf( stderr, "numtracks: no audio CD inserted in %s\n", 
	      CDROM_DEVICE );
     exit(1);
 }

 /* Read the toc header */
 if( ( d=ioctl( drive, CDROMREADTOCHDR, tochdr ) ) < 0 )
 {
   fprintf( stderr, "numtracks: reading toc header failed for device %s\n",
	    CDROM_DEVICE );
   exit( 1 );
 }

 /* Write the number of tracks */
 printf( "%d\n", tochdr->cdth_trk1 );

 /* Close the connection with the drive */
 close( drive );
 
 return 0;
 
}
